LineCursor class

Cursor for navigating through parsed lines

Constructors

LineCursor(List<ParsedLine> lines, List<BlankLineInfo> blankLines)

Properties

blankLines → List<BlankLineInfo>
final
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int
getter/setter pair
length → int
no setter
lines → List<ParsedLine>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

advance() → void
atEnd() → bool
current() → ParsedLine?
getBlankLines() → List<BlankLineInfo>
hasMoreAtDepth(int targetDepth) → bool
next() → ParsedLine?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peek() → ParsedLine?
peekAtDepth(int targetDepth) → ParsedLine?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited