ScanResult class

Result of scanning source text into parsed lines

Constructors

ScanResult({required List<ParsedLine> lines, required List<BlankLineInfo> blankLines})
const

Properties

blankLines → List<BlankLineInfo>
final
hashCode → int
The hash code for this object.
no setterinherited
lines → List<ParsedLine>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited