ArrayHeaderInfo class

Information about an array header

Constructors

ArrayHeaderInfo({String? key, required int length, required Delimiter delimiter, List<String>? fields, bool hasLengthMarker = false})
const

Properties

delimiter → Delimiter
final
fields → List<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
hasLengthMarker → bool
final
key → String?
final
length → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → Delimiter
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited