BlankLineInfo class

Information about blank lines

Constructors

BlankLineInfo({required int lineNumber, required int indent, required int depth})
const

Properties

depth → int
final
hashCode → int
The hash code for this object.
no setterinherited
indent → int
final
lineNumber → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → Delimiter
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited