DecodeOptions class

Options for decoding Toon format

Constructors

DecodeOptions({int indent = 2, bool strict = true})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
indent → int
Number of spaces per indentation level. @default 2
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strict → bool
When true, enforce strict validation of array lengths and tabular row counts. @default true
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → Delimiter
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited