EncodeOptions class

Options for encoding Toon format

Constructors

EncodeOptions({int indent = 2, Delimiter? delimiter, String? lengthMarker})
const

Properties

delimiter → Delimiter
Delimiter to use for tabular array rows and inline primitive arrays. @default DELIMITERS.comma
final
hashCode → int
The hash code for this object.
no setterinherited
indent → int
Number of spaces per indentation level. @default 2
final
lengthMarker → String?
Optional marker to prefix array lengths in headers. When set to #, arrays render as #N instead of N. @default false
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → Delimiter
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited