ParsedLine class

Represents a parsed line from the source

Constructors

ParsedLine({required String raw, required int depth, required int indent, required String content, required int lineNumber})
const

Properties

content → Delimiter
final
depth → int
final
hashCode → int
The hash code for this object.
no setterinherited
indent → int
final
lineNumber → int
final
raw → Delimiter
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → Delimiter
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited